@@ -2,4 +2,8 @@ from .agent_workflow import agent_workflow_span  # noqa: F401
 from .ai_client import ai_client_span, update_ai_client_span  # noqa: F401
 from .execute_tool import execute_tool_span, update_execute_tool_span  # noqa: F401
 from .handoff import handoff_span  # noqa: F401
-from .invoke_agent import invoke_agent_span, update_invoke_agent_span  # noqa: F401
+from .invoke_agent import (
+    invoke_agent_span,
+    update_invoke_agent_span,
+    end_invoke_agent_span,
+)  # noqa: F401
